==> estateplat-common-1.2.3-20180727.025448-157-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2017/1/16
 * @description 不动产警示信息
 */
@Table(name = "bdc_jsxx")
public class BdcJsxx implements Serializable {
    @Id
    private String jsid; //警示ID
    private String cqzh; //产权证号
    private String bdcdyh; //不动产单元号
    private String zsid;  //证书ID
    private String qlr;   //权利人
    private String zl;    //坐落
    private String bdclx; //不动产类型
    private String jszt;  //警示状态
    private String jsyy;  //警示原因
    private Date jssj;    //警示时间
    private String jbr;   //经办人
    private String qxr;   //取消人
    private Date qxsj;    //取消时间
    private String qxyy;  //取消原因


    public String getJsid() {
        return jsid;
    }

    public void setJsid(String jsid) {
        this.jsid = jsid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getJszt() {
        return jszt;
    }

    public void setJszt(String jszt) {
        this.jszt = jszt;
    }

    public String getJsyy() {
        return jsyy;
    }

    public void setJsyy(String jsyy) {
        this.jsyy = jsyy;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getQxr() {
        return qxr;
    }

    public void setQxr(String qxr) {
        this.qxr = qxr;
    }

    public Date getQxsj() {
        return qxsj;
    }

    public void setQxsj(Date qxsj) {
        this.qxsj = qxsj;
    }

    public String getQxyy() {
        return qxyy;
    }

    public void setQxyy(String qxyy) {
        this.qxyy = qxyy;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }


}

==> estateplat-common-1.2.4-20241107.014146-1268-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2017/1/16
 * @description 不动产警示信息
 */
@Table(name = "bdc_jsxx")
public class BdcJsxx implements Serializable {
    @Id
    private String jsid; //警示ID
    private String cqzh; //产权证号
    private String bdcdyh; //不动产单元号
    private String zsid;  //证书ID
    private String qlr;   //权利人
    private String zl;    //坐落
    private String bdclx; //不动产类型
    private String jszt;  //警示状态
    private String jsyy;  //警示原因
    private Date jssj;    //警示时间
    private String jbr;   //经办人
    private String qxr;   //取消人
    private Date qxsj;    //取消时间
    private String qxyy;  //取消原因
    private String xgr;  //修改人
    private Date xgsj;  //修改时间
    private String xgqjsyy;  //修改前警示原因


    public String getJsid() {
        return jsid;
    }

    public void setJsid(String jsid) {
        this.jsid = jsid;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getJszt() {
        return jszt;
    }

    public void setJszt(String jszt) {
        this.jszt = jszt;
    }

    public String getJsyy() {
        return jsyy;
    }

    public void setJsyy(String jsyy) {
        this.jsyy = jsyy;
    }

    public Date getJssj() {
        return jssj;
    }

    public void setJssj(Date jssj) {
        this.jssj = jssj;
    }

    public String getJbr() {
        return jbr;
    }

    public void setJbr(String jbr) {
        this.jbr = jbr;
    }

    public String getQxr() {
        return qxr;
    }

    public void setQxr(String qxr) {
        this.qxr = qxr;
    }

    public Date getQxsj() {
        return qxsj;
    }

    public void setQxsj(Date qxsj) {
        this.qxsj = qxsj;
    }

    public String getQxyy() {
        return qxyy;
    }

    public void setQxyy(String qxyy) {
        this.qxyy = qxyy;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getXgr() {
        return xgr;
    }

    public void setXgr(String xgr) {
        this.xgr = xgr;
    }

    public Date getXgsj() {
        return xgsj;
    }

    public void setXgsj(Date xgsj) {
        this.xgsj = xgsj;
    }

    public String getXgqjsyy() {
        return xgqjsyy;
    }

    public void setXgqjsyy(String xgqjsyy) {
        this.xgqjsyy = xgqjsyy;
    }
}
